@@ -20,7 +20,9 @@
 #include <QtGui/QApplication>
 #include <QtCore/QTranslator>
 #include <QtCore/QLibraryInfo>
+#include <QtCore/QLocale>
 #include <QtCore/QtPlugin>
+#include <QtCore/QDir>
 
 #include "config.h"
 
@@ -42,6 +44,7 @@ Q_IMPORT_PLUGIN(stationsaustria);
 Q_IMPORT_PLUGIN(stationsloweraustria);
 Q_IMPORT_PLUGIN(stationslatvia);
 Q_IMPORT_PLUGIN(stationsnewzealand);
+Q_IMPORT_PLUGIN(stationsusa);
 #endif
 
 int main(int argc, char *argv[])
@@ -62,6 +65,7 @@ int main(int argc, char *argv[])
     Q_INIT_RESOURCE(lower_austria);
     Q_INIT_RESOURCE(latvia);
     Q_INIT_RESOURCE(new_zealand);
+    Q_INIT_RESOURCE(usa);
 #endif
 
     QTranslator qtTranslator;
@@ -77,6 +81,15 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationName("Lugdulov");
     QCoreApplication::setApplicationVersion(LUGDULOV_VERSION);
 
+#if defined(Q_OS_MAC) || defined(Q_OS_WINDOWS)
+    QDir dir(QApplication::applicationDirPath());
+#if defined(Q_OS_MAC)
+    dir.cdUp();
+#endif
+    dir.cd("plugins");
+    QApplication::setLibraryPaths(QStringList(dir.absolutePath()));
+#endif
+
     Settings::settings();
 
     MainWindow w;
