@@ -19,17 +19,15 @@
 #ifndef STATIONSLISTDIALOG_H
 # define STATIONSLISTDIALOG_H
 
+#include <QtCore/QTimer>
+#include <QtGui/QDialog>
+
 #include "mobility.h"
 
-#include "ui_stationslistdialog.h"
-
-class StationsModel;
 class StationsPlugin;
-class Station;
-class StationsSortFilterProxyModel;
-class StationsView;
+class Ui_StationsListDialog;
 
-class StationsListDialog : public QDialog, private Ui_StationsListDialog
+class StationsListDialog : public QDialog
 {
   Q_OBJECT
 
@@ -37,28 +35,19 @@ class StationsListDialog : public QDialog, private Ui_StationsListDialog
   StationsListDialog(StationsPlugin *plugin, QWidget *parent = 0);
   ~StationsListDialog();
 
-#ifdef HAVE_QT_LOCATION
  public slots:
+  void onlyBookmarks(bool enabled);
+#ifdef HAVE_QT_LOCATION
   void positionUpdated(QGeoPositionInfo info);
   void positionRequestTimeout();
 #endif
 
- private:
-  void setupListWidget();
-
  private slots:
-  void filter(const QString & text);
   void progress(qint64 done, qint64 total);
   void error(const QString & title, const QString & message);
 
- protected:
-  StationsPlugin *plugin;
-  StationsModel *model;
-  StationsSortFilterProxyModel *proxy;
-  StationsView *view;
-#ifdef HAVE_QT_LOCATION
-  QGeoPositionInfo position;
-#endif
+ private:
+  Ui_StationsListDialog *ui;
 };
 
 #endif
