@@ -121,9 +121,10 @@ StationsListView::action(QAction *action)
 
        map->centerView(station->pos());
        showAndDelete(map);
-    } else if (action == bookmark)
-      Settings::bookmark(station, !Settings::bookmarked(station));
-    else if (plugin)
+    } else if (action == bookmark) {
+      model()->setData(index, !Settings::bookmarked(station),
+		       StationsModel::StationBookmarkRole);
+    } else if (plugin)
 	plugin->actionTriggered(action, station, this);
   }
 }
@@ -170,6 +171,8 @@ StationsListView::update()
   QModelIndex index;
   QModelIndexList list;
 
+  if (!plugin)
+    return ;
   while (viewport()->rect().contains(0, rect.y() + rect.height() + 1)){
     index = indexAt(QPoint(rect.x(), rect.y() + rect.height() + 1));
 
@@ -187,6 +190,7 @@ StationsListView::update()
 
     plugin->updateCached(station);
   }
+  scrollTimer->stop();
 }
 
 void
