@@ -18,39 +18,22 @@
 
 #include <QtCore/QtPlugin>
 
+
 #include "factory.h"
-#include "neusiedler_see.h"
-#include "bregenzerwald.h"
 #include "wien.h"
 
-QString
-StationsPluginFactoryAustria::id() const
+StationsPluginFactoryAustria::StationsPluginFactoryAustria()
 {
-  return QLatin1String("Austria");
+  init("austria");
 }
 
-QString
-StationsPluginFactoryAustria::name() const
+StationsPluginSimple *
+StationsPluginFactoryAustria::pluginForType(const QString & type)
 {
-  return QString::fromUtf8("Austria");
-}
-
-QIcon
-StationsPluginFactoryAustria::icon() const
-{
-  return QIcon(":/austria/at.png");
-}
-
-QList < StationsPlugin * >
-StationsPluginFactoryAustria::stations(QObject *parent)
-{
-  QList < StationsPlugin * > ret;
-
-  ret << new StationsPluginNeusiedler_See(parent);
-  ret << new StationsPluginBregenzerwald(parent);
-  ret << new StationsPluginWien(parent);
-
-  return ret;
+  if (type == "Wien" || type == "CityBikeWien")
+    return new StationsPluginWien();
+  else
+    return StationsPluginFactorySimple::pluginForType(type);
 }
 
 Q_EXPORT_PLUGIN2(stationsaustria, StationsPluginFactoryAustria)
