@@ -18,34 +18,12 @@
 
 #include <QtCore/QtPlugin>
 
+
 #include "factory.h"
-#include "bruxelles.h"
 
-QString
-StationsPluginFactoryBelgium::id() const
+StationsPluginFactoryBelgium::StationsPluginFactoryBelgium()
 {
-  return QLatin1String("Belgium");
-}
-
-QString
-StationsPluginFactoryBelgium::name() const
-{
-  return QString::fromUtf8("Réseaux Belges");
-}
-
-QIcon
-StationsPluginFactoryBelgium::icon() const
-{
-  return QIcon(":/belgium/be.png");
-}
-
-QList < StationsPlugin * >
-StationsPluginFactoryBelgium::stations(QObject *parent)
-{
-  QList < StationsPlugin * > ret;
-
-  ret << new StationsPluginBruxelles(parent);
-  return ret;
+  init("belgium");
 }
 
 Q_EXPORT_PLUGIN2(stationsbelgium, StationsPluginFactoryBelgium)
