@@ -18,36 +18,12 @@
 
 #include <QtCore/QtPlugin>
 
+
 #include "factory.h"
-#include "montreal.h"
 
-
-QString
-StationsPluginFactoryCanada::id() const
+StationsPluginFactoryCanada::StationsPluginFactoryCanada()
 {
-  return QLatin1String("Canada");
-}
-
-QString
-StationsPluginFactoryCanada::name() const
-{
-  return QString::fromUtf8("CanadaNetworks");
-}
-
-QIcon
-StationsPluginFactoryCanada::icon() const
-{
-  return QIcon(":/canada/ca.png");
-}
-
-QList < StationsPlugin * >
-StationsPluginFactoryCanada::stations(QObject *parent)
-{
-  QList < StationsPlugin * > ret;
-
-  ret << new StationsPluginMontreal(parent);
-
-  return ret;
+  init("canada");
 }
 
 Q_EXPORT_PLUGIN2(stationscanada, StationsPluginFactoryCanada)
