@@ -19,18 +19,14 @@
 #ifndef STATIONS_CANADA_H
 #define STATIONS_CANADA_H
 
-#include "stationsplugin.h"
+#include "stationspluginfactorysimple.h"
 
-class Station;
-class StationsPluginFactoryCanada : public QObject, public StationsPluginFactory
+class StationsPluginFactoryCanada : public QObject, public StationsPluginFactorySimple
 {
   Q_OBJECT
   Q_INTERFACES(StationsPluginFactory)
  public:
-  QString id() const;
-  QString name() const;
-  QIcon icon() const;
-  QList < StationsPlugin * > stations(QObject * parent);
+  StationsPluginFactoryCanada();
 };
 
 #endif /* STATIONS_CANADA_H */
