@@ -19,10 +19,6 @@
 #ifndef STATIONS_ORLEANS_H
 #define STATIONS_ORLEANS_H
 
-#include <QtNetwork/QNetworkAccessManager>
-#include <QtNetwork/QNetworkReply>
-#include <QtCore/QMap>
-
 #include "stationspluginsimple.h"
 
 class Station;
@@ -31,14 +27,9 @@ class StationsPluginOrleans : public StationsPluginSimple
 {
   Q_OBJECT
  public:
-  StationsPluginOrleans(QObject *parent);
+  StationsPluginOrleans(QObject *parent = NULL);
   ~StationsPluginOrleans();
 
-  QString id() const;
-  QString name() const;
-  QString bikeName() const;
-  QIcon bikeIcon() const;
-
  private:
   void handleInfos(const QByteArray & data);
   void handleStatus(const QByteArray & data, int id);
