@@ -18,34 +18,12 @@
 
 #include <QtCore/QtPlugin>
 
+
 #include "factory.h"
-#include "dublin.h"
 
-QString
-StationsPluginFactoryIreland::id() const
+StationsPluginFactoryIreland::StationsPluginFactoryIreland()
 {
-  return QLatin1String("Ireland");
-}
-
-QString
-StationsPluginFactoryIreland::name() const
-{
-  return QString::fromUtf8("Irish Networks");
-}
-
-QIcon
-StationsPluginFactoryIreland::icon() const
-{
-  return QIcon(":/ireland/ir.png");
-}
-
-QList < StationsPlugin * >
-StationsPluginFactoryIreland::stations(QObject *parent)
-{
-  QList < StationsPlugin * > ret;
-
-  ret << new StationsPluginDublin(parent);
-  return ret;
+  init("ireland");
 }
 
 Q_EXPORT_PLUGIN2(stationsireland, StationsPluginFactoryIreland)
