@@ -18,34 +18,12 @@
 
 #include <QtCore/QtPlugin>
 
+
 #include "factory.h"
-#include "toyama.h"
 
-QString
-StationsPluginFactoryJapan::id() const
+StationsPluginFactoryJapan::StationsPluginFactoryJapan()
 {
-  return QLatin1String("Japan");
-}
-
-QString
-StationsPluginFactoryJapan::name() const
-{
-  return QString::fromUtf8("Japan");
-}
-
-QIcon
-StationsPluginFactoryJapan::icon() const
-{
-  return QIcon(":/japan/jp.png");
-}
-
-QList < StationsPlugin * >
-StationsPluginFactoryJapan::stations(QObject *parent)
-{
-  QList < StationsPlugin * > ret;
-
-  ret << new StationsPluginToyama(parent);
-  return ret;
+  init("japan");
 }
 
 Q_EXPORT_PLUGIN2(stationsjapan, StationsPluginFactoryJapan)
