@@ -18,36 +18,12 @@
 
 #include <QtCore/QtPlugin>
 
+
 #include "factory.h"
-#include "auckland.h"
 
-
-QString
-StationsPluginFactoryNewZealand::id() const
+StationsPluginFactoryNewZealand::StationsPluginFactoryNewZealand()
 {
-  return QLatin1String("NewZealand");
-}
-
-QString
-StationsPluginFactoryNewZealand::name() const
-{
-  return QString::fromUtf8("New Zealand");
-}
-
-QIcon
-StationsPluginFactoryNewZealand::icon() const
-{
-  return QIcon(":/new-zealand/nz.png");
-}
-
-QList < StationsPlugin * >
-StationsPluginFactoryNewZealand::stations(QObject *parent)
-{
-  QList < StationsPlugin * > ret;
-
-  ret << new StationsPluginAuckland(parent);
-
-  return ret;
+  init("new-zealand");
 }
 
 Q_EXPORT_PLUGIN2(stationsnewzealand, StationsPluginFactoryNewZealand)
